@@ -1,6 +1,6 @@
 import math
 from collections import OrderedDict
-from datetime import datetime
+from datetime import datetime, date
 
 import pandas as pd
 import pyarrow as pa
@@ -33,6 +33,13 @@ def test_schema_init():
     assert 0 == len(Schema(""))
 
 
+def test_schema_datetime():
+    df = pd.DataFrame(
+        [[datetime(2020, 1, 1, 2, 3, 4, 5), date(2020, 2, 2)]], columns=["a", "b"]
+    )
+    assert Schema(df) == "a:datetime,b:date"
+
+
 def test_schema_properties():
     s = Schema("a:int,b:str")
     assert ["a", "b"] == s.names
@@ -288,7 +295,13 @@ def test_schema_transform():
     assert s.transform("*,d:str") == "a:int,b:str,c:bool,d:str"
     assert s.transform("*,d:str - a ") == "b:str,c:bool,d:str"
     assert s.transform("*,d:str - c,,a ") == "b:str,d:str"
+    assert s.transform("*,d:str - c-a") == "b:str,d:str"
     assert s.transform("*,d:str ~ c,,a,x ") == "b:str,d:str"
+    assert s.transform("*,d:str ~ c-a~x") == "b:str,d:str"
+    assert s.transform("* + e:int,b:int,d:str") == "a:int,b:int,c:bool,e:int,d:str"
+    # multiple operations will be applied in order
+    assert s.transform("*+e:int,b:int-c~x,c") == "a:int,b:int,e:int"
+    assert s.transform("* + - ~ ") == s  # no op
     assert s.transform("*", {"d": str}, e=str) == "a:int,b:str,c:bool,d:str,e:str"
     assert s.transform(lambda s: s.fields[0], lambda s: s.fields[2]) == "a:int,c:bool"
     assert s.transform(lambda s: s - ["b"]) == "a:int,c:bool"
